cxroots: rootfinding for complex analytic functions — cxroots 1.1.0 documentation

# cxroots: rootfinding for complex analytic functions

cxroots is a Python library for finding all the roots of a complex analytic function of a single complex variable within a given contour in the complex plane. The implementation is based on [1].

The cxroots code is hosted at GitHub and is open source under a BSD 3-Clause License

## Documentation

Getting Started

- Installation
- Tutorial
  - Contours
  - Rootfinding

User Guides

- Demonstrating Rootfinding
- Using Known Roots or Symmetries
  - Guessing Roots
  - Guessing Root Symmetry

Examples

- Stability of an Annular Combustion Chamber
  - References

Reference

- Paths
  - Line
  - Circular Arc
- Contours
  - Circle
  - Rectangle
  - Annulus
  - Annulus Sector
- Symmetric Bilinear Form
- Iterative Methods
- Rootfinding Result

## References

[1] Peter Kravanja and Marc Van Barel. “Computing the Zeros of Analytic Functions”. Springer Berlin Heidelberg, 2000.